Stan Math Library: stan/math/rev/scal/fun/log1p_exp.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

log1p_exp.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_FUN_LOG1P_EXP_HPP
2 #define STAN_MATH_REV_SCAL_FUN_LOG1P_EXP_HPP
3
4 #include <stan/math/rev/core.hpp>
5 #include <stan/math/prim/scal/fun/log1p_exp.hpp>
6 #include <stan/math/rev/scal/fun/calculate_chain.hpp>
7
8 namespace stan {
9 namespace math {
10
11 namespace {
12 class log1p_exp_v_vari : public op_v_vari {
13 public:
14 explicit log1p_exp_v_vari(vari* avi) :
15 op_v_vari(stan::math::log1p_exp(avi->val_),
16 avi) {
17 }
18 void chain() {
19 avi_->adj_ += adj_ * calculate_chain(avi_->val_, val_);
20 }
21 };
22 }
23
28 inline var log1p_exp(const stan::math::var& a) {
29 return var(new log1p_exp_v_vari(a.vi_));
30 }
31
32 }
33 }
34 #endif
core.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
stan::math::calculate_chain
double calculate_chain(const double &x, const double &val)
Definition: calculate_chain.hpp:8
stan::math::var::vi_
vari * vi_
Pointer to the implementation of this variable.
Definition: var.hpp:43
log1p_exp.hpp
calculate_chain.hpp
stan::math::log1p_exp
fvar< T > log1p_exp(const fvar< T > &x)
Definition: log1p_exp.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.